#
# PySNMP MIB module ATM-TC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ATM-TC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:06:16 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "ConstraintsUnion", "ValueSizeConstraint")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( ObjectIdentity, MibIdentifier, Gauge32, Counter32, ModuleIdentity, Integer32, Bits, Counter64, mib_2, iso, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, IpAddress, Unsigned32, TimeTicks, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ObjectIdentity", "MibIdentifier", "Gauge32", "Counter32", "ModuleIdentity", "Integer32", "Bits", "Counter64", "mib-2", "iso", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "IpAddress", "Unsigned32", "TimeTicks")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
atmTCMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 37, 3))
if mibBuilder.loadTexts: atmTCMIB.setLastUpdated('9810190200Z')
if mibBuilder.loadTexts: atmTCMIB.setOrganization('IETF AToMMIB Working Group')
if mibBuilder.loadTexts: atmTCMIB.setContactInfo('          Michael Noto\n              Postal:  3Com Corporation\n                       5400 Bayfront Plaza, M/S 3109\n                       Santa Clara, CA 95052\n                       USA\n              Tel:     +1 408 326 2218\n              E-mail:  mike_noto@3com.com\n            \n                       Ethan Mickey Spiegel\n            \n              Postal:  Cisco Systems\n                       170 W. Tasman Dr.\n                       San Jose, CA 95134\n                       USA\n              Tel:     +1 408 526 6408\n              E-mail:  mspiegel@cisco.com\n            \n                       Kaj Tesink\n              Postal:  Bellcore\n                       331 Newman Springs Road\n                       Red Bank, NJ 07701\n                       USA\n              Tel:     +1 732 758 5254\n              Fax:     +1 732 758 4177\n              E-mail:  kaj@bellcore.com')
if mibBuilder.loadTexts: atmTCMIB.setDescription('This MIB Module provides Textual Conventions\n            and OBJECT-IDENTITY Objects to be used by\n            ATM systems.')
class AtmAddr(OctetString, TextualConvention):
    displayHint = '1x'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,40)

class AtmConnCastType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("p2p", 1), ("p2mpRoot", 2), ("p2mpLeaf", 3),)

class AtmConnKind(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))
    namedValues = NamedValues(("pvc", 1), ("svcIncoming", 2), ("svcOutgoing", 3), ("spvcInitiator", 4), ("spvcTarget", 5),)

class AtmIlmiNetworkPrefix(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ConstraintsUnion(ValueSizeConstraint(8,8),ValueSizeConstraint(13,13),)
class AtmInterfaceType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13,))
    namedValues = NamedValues(("other", 1), ("autoConfig", 2), ("ituDss2", 3), ("atmfUni3Dot0", 4), ("atmfUni3Dot1", 5), ("atmfUni4Dot0", 6), ("atmfIispUni3Dot0", 7), ("atmfIispUni3Dot1", 8), ("atmfIispUni4Dot0", 9), ("atmfPnni1Dot0", 10), ("atmfBici2Dot0", 11), ("atmfUniPvcOnly", 12), ("atmfNniPvcOnly", 13),)

class AtmServiceCategory(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))
    namedValues = NamedValues(("other", 1), ("cbr", 2), ("rtVbr", 3), ("nrtVbr", 4), ("abr", 5), ("ubr", 6),)

class AtmSigDescrParamIndex(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

class AtmTrafficDescrParamIndex(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,2147483647)

class AtmVcIdentifier(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,65535)

class AtmVpIdentifier(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,4095)

class AtmVorXAdminStatus(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("up", 1), ("down", 2),)

class AtmVorXLastChange(TimeTicks, TextualConvention):
    pass

class AtmVorXOperStatus(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("up", 1), ("down", 2), ("unknown", 3),)

atmTrafficDescriptorTypes = MibIdentifier((1, 3, 6, 1, 2, 1, 37, 1, 1))
atmObjectIdentities = MibIdentifier((1, 3, 6, 1, 2, 1, 37, 3, 1))
atmNoTrafficDescriptor = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 1))
if mibBuilder.loadTexts: atmNoTrafficDescriptor.setDescription('This identifies the no ATM traffic\n            descriptor type.  Parameters 1, 2, 3, 4,\n            and 5 are not used.  This traffic descriptor\n            type can be used for best effort traffic.')
atmNoClpNoScr = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 2))
if mibBuilder.loadTexts: atmNoClpNoScr.setDescription('This traffic descriptor type is for no CLP\n            and no Sustained Cell Rate.  The use of the\n            parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: not used\n                Parameter 3: not used\n                Parameter 4: not used\n                Parameter 5: not used.')
atmClpNoTaggingNoScr = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 3))
if mibBuilder.loadTexts: atmClpNoTaggingNoScr.setDescription('This traffic descriptor is for CLP without\n            tagging and no Sustained Cell Rate.  The use\n            of the parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: peak cell rate in cells/second\n                             for CLP=0 traffic\n                Parameter 3: not used\n                Parameter 4: not used\n                Parameter 5: not used.')
atmClpTaggingNoScr = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 4))
if mibBuilder.loadTexts: atmClpTaggingNoScr.setDescription('This traffic descriptor is for CLP with\n            tagging and no Sustained Cell Rate.  The use\n            of the parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: peak cell rate in cells/second\n                             for CLP=0 traffic, excess\n                             tagged as CLP=1\n                Parameter 3: not used\n                Parameter 4: not used\n                Parameter 5: not used.')
atmNoClpScr = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 5))
if mibBuilder.loadTexts: atmNoClpScr.setDescription('This traffic descriptor type is for no CLP\n            with Sustained Cell Rate.  The use of the\n            parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: sustainable cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 3: maximum burst size in cells\n                Parameter 4: not used\n                Parameter 5: not used.')
atmClpNoTaggingScr = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 6))
if mibBuilder.loadTexts: atmClpNoTaggingScr.setDescription('This traffic descriptor type is for CLP with\n            Sustained Cell Rate and no tagging.  The use\n            of the parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: sustainable cell rate in cells/second\n                             for CLP=0 traffic\n                Parameter 3: maximum burst size in cells\n                Parameter 4: not used\n                Parameter 5: not used.')
atmClpTaggingScr = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 7))
if mibBuilder.loadTexts: atmClpTaggingScr.setDescription('This traffic descriptor type is for CLP with\n            tagging and Sustained Cell Rate.  The use of\n            the parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: sustainable cell rate in cells/second\n                             for CLP=0 traffic, excess tagged as\n                             CLP=1\n                Parameter 3: maximum burst size in cells\n                Parameter 4: not used\n                Parameter 5: not used.')
atmClpNoTaggingMcr = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 8))
if mibBuilder.loadTexts: atmClpNoTaggingMcr.setDescription('This traffic descriptor type is for CLP with\n            Minimum Cell Rate and no tagging.  The use of\n            the parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: CDVT in tenths of microseconds\n                Parameter 3: minimum cell rate in cells/second\n                Parameter 4: unused\n                Parameter 5: unused.')
atmClpTransparentNoScr = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 9))
if mibBuilder.loadTexts: atmClpTransparentNoScr.setDescription('This traffic descriptor type is for the CLP-\n            transparent model and no Sustained Cell Rate.\n            The use of the parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: CDVT in tenths of microseconds\n                Parameter 3: not used\n                Parameter 4: not used\n                Parameter 5: not used.\n            \n            This traffic descriptor type is applicable to\n            connections following the CBR.1 conformance\n            definition.\n            \n            Connections specifying this traffic descriptor\n            type will be rejected at UNI 3.0 or UNI 3.1\n            interfaces.  For a similar traffic descriptor\n            type that can be accepted at UNI 3.0 and\n            UNI 3.1 interfaces, see atmNoClpNoScr.')
atmClpTransparentScr = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 10))
if mibBuilder.loadTexts: atmClpTransparentScr.setDescription('This traffic descriptor type is for the CLP-\n            transparent model with Sustained Cell Rate.\n            The use of the parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: sustainable cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 3: maximum burst size in cells\n                Parameter 4: CDVT in tenths of microseconds\n                Parameter 5: not used.\n            \n            This traffic descriptor type is applicable to\n            connections following the VBR.1 conformance\n            definition.\n            Connections specifying this traffic descriptor\n            type will be rejected at UNI 3.0 or UNI 3.1\n            interfaces.  For a similar traffic descriptor\n            type that can be accepted at UNI 3.0 and\n            UNI 3.1 interfaces, see atmNoClpScr.')
atmNoClpTaggingNoScr = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 11))
if mibBuilder.loadTexts: atmNoClpTaggingNoScr.setDescription('This traffic descriptor type is for no CLP\n            with tagging and no Sustained Cell Rate.  The\n            use of the parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: CDVT in tenths of microseconds\n                Parameter 3: not used\n                Parameter 4: not used\n                Parameter 5: not used.\n            \n            This traffic descriptor type is applicable to\n            connections following the UBR.2 conformance\n            definition .')
atmNoClpNoScrCdvt = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 12))
if mibBuilder.loadTexts: atmNoClpNoScrCdvt.setDescription('This traffic descriptor type is for no CLP\n            and no Sustained Cell Rate.  The use of the\n            parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: CDVT in tenths of microseconds\n                Parameter 3: not used\n                Parameter 4: not used\n                Parameter 5: not used.\n        \n            This traffic descriptor type is applicable to\n            CBR connections following the UNI 3.0/3.1\n            conformance definition for PCR CLP=0+1.\n            These CBR connections differ from CBR.1\n            connections in that the CLR objective\n            applies only to the CLP=0 cell flow.\n            \n            This traffic descriptor type is also\n            applicable to connections following the UBR.1\n            conformance definition.')
atmNoClpScrCdvt = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 13))
if mibBuilder.loadTexts: atmNoClpScrCdvt.setDescription('This traffic descriptor type is for no CLP\n            with Sustained Cell Rate.  The use of the\n            parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: sustainable cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 3: maximum burst size in cells\n                Parameter 4: CDVT in tenths of microseconds\n                Parameter 5: not used.\n            \n            This traffic descriptor type is applicable\n            to VBR connections following the UNI 3.0/3.1\n            conformance definition for PCR CLP=0+1 and\n            SCR CLP=0+1.  These VBR connections\n            differ from VBR.1 connections in that\n            the CLR objective applies only to the CLP=0\n            cell flow.')
atmClpNoTaggingScrCdvt = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 14))
if mibBuilder.loadTexts: atmClpNoTaggingScrCdvt.setDescription('This traffic descriptor type is for CLP with\n            Sustained Cell Rate and no tagging.  The use\n            of the parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: sustainable cell rate in cells/second\n                             for CLP=0 traffic\n                Parameter 3: maximum burst size in cells\n                Parameter 4: CDVT in tenths of microseconds\n                Parameter 5: not used.\n            \n            This traffic descriptor type is applicable to\n            connections following the VBR.2 conformance\n            definition.')
atmClpTaggingScrCdvt = ObjectIdentity((1, 3, 6, 1, 2, 1, 37, 1, 1, 15))
if mibBuilder.loadTexts: atmClpTaggingScrCdvt.setDescription('This traffic descriptor type is for CLP with\n            tagging and Sustained Cell Rate.  The use of\n            the parameter vector for this type:\n                Parameter 1: peak cell rate in cells/second\n                             for CLP=0+1 traffic\n                Parameter 2: sustainable cell rate in cells/second\n                             for CLP=0 traffic, excess tagged as\n                             CLP=1\n                Parameter 3: maximum burst size in cells\n                Parameter 4: CDVT in tenths of microseconds\n                Parameter 5: not used.\n            \n            This traffic descriptor type is applicable to\n            connections following the VBR.3 conformance\n            definition.')
mibBuilder.exportSymbols("ATM-TC-MIB", atmNoClpNoScr=atmNoClpNoScr, atmTrafficDescriptorTypes=atmTrafficDescriptorTypes, atmObjectIdentities=atmObjectIdentities, AtmVorXAdminStatus=AtmVorXAdminStatus, atmNoClpScr=atmNoClpScr, PYSNMP_MODULE_ID=atmTCMIB, AtmAddr=AtmAddr, atmClpNoTaggingNoScr=atmClpNoTaggingNoScr, AtmIlmiNetworkPrefix=AtmIlmiNetworkPrefix, atmClpTaggingNoScr=atmClpTaggingNoScr, atmClpNoTaggingMcr=atmClpNoTaggingMcr, atmNoClpTaggingNoScr=atmNoClpTaggingNoScr, atmClpTaggingScrCdvt=atmClpTaggingScrCdvt, AtmVcIdentifier=AtmVcIdentifier, atmNoClpScrCdvt=atmNoClpScrCdvt, atmTCMIB=atmTCMIB, atmClpNoTaggingScrCdvt=atmClpNoTaggingScrCdvt, atmClpTransparentScr=atmClpTransparentScr, AtmSigDescrParamIndex=AtmSigDescrParamIndex, AtmServiceCategory=AtmServiceCategory, AtmConnCastType=AtmConnCastType, AtmTrafficDescrParamIndex=AtmTrafficDescrParamIndex, AtmVorXLastChange=AtmVorXLastChange, atmClpNoTaggingScr=atmClpNoTaggingScr, AtmVorXOperStatus=AtmVorXOperStatus, AtmVpIdentifier=AtmVpIdentifier, atmNoTrafficDescriptor=atmNoTrafficDescriptor, atmNoClpNoScrCdvt=atmNoClpNoScrCdvt, atmClpTransparentNoScr=atmClpTransparentNoScr, AtmConnKind=AtmConnKind, atmClpTaggingScr=atmClpTaggingScr, AtmInterfaceType=AtmInterfaceType)



#
# PySNMP MIB module T11-FC-FABRIC-LOCK-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/T11-FC-FABRIC-LOCK-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:29:58 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ConstraintsIntersection")
( fcmInstanceIndex, fcmSwitchIndex, ) = mibBuilder.importSymbols("FC-MGMT-MIB", "fcmInstanceIndex", "fcmSwitchIndex")
( InetAddressType, InetAddress, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressType", "InetAddress")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( MibIdentifier, Unsigned32, ModuleIdentity, Counter64, Bits, Gauge32, IpAddress, mib_2, Counter32, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, iso, TimeTicks, ObjectIdentity, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibIdentifier", "Unsigned32", "ModuleIdentity", "Counter64", "Bits", "Gauge32", "IpAddress", "mib-2", "Counter32", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "TimeTicks", "ObjectIdentity", "Integer32")
( RowStatus, DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "DisplayString", "TextualConvention")
( T11NsGs4RejectReasonCode, ) = mibBuilder.importSymbols("T11-FC-NAME-SERVER-MIB", "T11NsGs4RejectReasonCode")
( T11FabricIndex, ) = mibBuilder.importSymbols("T11-TC-MIB", "T11FabricIndex")
t11FabricLockMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 159)).setRevisions(("2007-06-27 00:00",))
if mibBuilder.loadTexts: t11FabricLockMIB.setLastUpdated('200706270000Z')
if mibBuilder.loadTexts: t11FabricLockMIB.setOrganization("For the initial versions, T11.\n                   For later versions, the IETF's IMSS Working Group.")
if mibBuilder.loadTexts: t11FabricLockMIB.setContactInfo('      Claudio DeSanti\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive\n                  San Jose, CA 95134 USA\n                  EMail: cds@cisco.com\n\n                  Keith McCloghrie\n\n\n\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive\n                  San Jose, CA 95134 USA\n                  EMail: kzm@cisco.com')
if mibBuilder.loadTexts: t11FabricLockMIB.setDescription("The MIB module for the management of locks on a Fibre\n           Channel Fabric.  A Fibre Channel Fabric lock is used to\n           ensure serialized access to some types of management data\n           related to a Fabric, e.g., the Fabric's Zoning Database.\n\n           Some (managing) applications generate Fabric locks by\n           initiating server sessions.  Server sessions are\n           defined generically in FC-GS-5 to represent a collection of\n           one or more requests to the session's server, e.g., to the\n           Zone Server.  Such a session is started by a Server Session\n           Begin (SSB) request, and terminated by a Server Session End\n           (SSE) request.  The switch receiving the SSB is called the\n           'managing' switch.  Some applications require the\n           'managing' switch to lock the Fabric for the particular\n           application, e.g., for Enhanced Zoning, before it can\n           respond successfully to the SSB.  On receipt of the\n           subsequent SSE, the lock is released.  For this usage, the\n           managing switch sends an Acquire Change Authorization (ACA)\n           request to other switches to lock the Fabric.\n\n           For some other applications, a managing switch locks the\n           Fabric using an Enhanced Acquire Change Authorization (EACA)\n           request, which identifies the application on whose behalf\n           the Fabric is being locked with an Application_ID.\n\n           Fabric locks can also be requested more directly, e.g.,\n           through the use of this MIB.  In these situations, the term\n           'managing' switch is used to indicate the switch that\n           receives such a request and executes it by issuing either\n           ACA or EACA requests to other switches in the Fabric.\n\n           This MIB module defines information about the 'managing'\n           switch for currently-active Fabric locks.\n\n           Copyright (C) The IETF Trust (2007).  This version\n           of this MIB module is part of RFC 4936;  see the RFC\n           itself for full legal notices.")
t11FLockMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 159, 1))
t11FLockMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 159, 2))
t11FLockMIBNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 159, 0))
t11FLockConfiguration = MibIdentifier((1, 3, 6, 1, 2, 1, 159, 1, 1))
t11FLockTable = MibTable((1, 3, 6, 1, 2, 1, 159, 1, 1, 1), )
if mibBuilder.loadTexts: t11FLockTable.setDescription("A table containing information about the 'managing'\n           switch of each current Fabric lock, e.g., for the\n           types of Servers defined in FC-GS-5.\n\n           Each entry in this table represents either:\n\n           1) a current Fabric lock,\n           2) an in-progress attempt, requested via SNMP, to set up\n              a lock, or\n           3) a failed attempt, requested via SNMP, to set up a lock.\n\n           If an entry is created via t11FLockRowStatus, but the\n           attempt to obtain the lock fails, then the entry continues\n           to exist until it is deleted via t11FLockRowStatus, or\n           it is overwritten by the lock being established via\n           a means other than SNMP.  However, rows created via\n           t11FLockRowStatus are not retained over restarts.")
t11FLockEntry = MibTableRow((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-FABRIC-LOCK-MIB", "t11FLockFabricIndex"), (0, "T11-FC-FABRIC-LOCK-MIB", "t11FLockApplicationID"))
if mibBuilder.loadTexts: t11FLockEntry.setDescription("Each entry contains information specific to a current\n           Fabric lock set up by a particular 'managing' switch on a\n           particular Fabric.  The 'managing switch' is identified by\n           values of fcmInstanceIndex and fcmSwitchIndex.\n\n           Server sessions for several different types of servers\n           are defined in FC-GS-5.  The behavior of a server with\n\n\n\n           respect to commands received within a server session is\n           specified for each type of server.  For some types,\n           parameter changes can only be made within the context of a\n           session, and the setting up of a session requires that the\n           Fabric be locked.  A Fabric is locked by one switch, called\n           the 'managing' switch, sending Acquire Change Authorization\n           (ACA) requests to all other switches in the Fabric.\n\n           For other applications, a Fabric lock is established by the\n           'managing' switch sending Enhanced Acquire Change\n           Authorization (EACA) requests to other switches in the\n           Fabric.  Each EACA request includes an Application_ID\n           value to identify the application requesting the lock.\n\n           For the benefit of this MIB module, a distinct value of\n           Application_ID has also been assigned/reserved (see\n           ANSI INCITS T11/06-679v0, titled 'FC-SW-5 Letter to\n           T11.5') as a means of distinguishing locks established via\n           Acquire Change Authorization (ACA) requests.  This\n           additional assignment allows an Application_ID to be used to\n           uniquely identify any active lock amongst all those\n           established by either an EACA or an ACA.\n\n           Whenever a Fabric is locked, by the sending of either an ACA\n           or an EACA, a row gets created in the representation of this\n           table for the 'managing' switch.\n\n           In order to process SNMP SetRequests that make parameter\n           changes for the relevant types of servers (e.g., to the\n           Zoning Database), the SNMP agent must get serialized access\n           to the Fabric (for the relevant type of management data),\n           i.e., the Fabric must be locked by creating an entry in\n           this table via an SNMP SetRequest.  Creating an entry in\n           this table via an SNMP SetRequest causes an ACA or an EACA\n           to be sent to all other switches in the Fabric.  The value\n           of t11FLockApplicationID for such an entry determines\n           whether an ACA or an EACA is sent.\n\n           If an entry in this table is created by an SNMP SetRequest,\n           the value of the t11FLockInitiatorType object in that entry\n           will normally be 'snmp'.  A row for which the value of\n           t11FLockInitiatorType is not 'snmp' cannot be modified\n           via SNMP.  In particular, it cannot be deleted via\n           t11FLockRowStatus.  Note that it's possible for a row to be\n           created by an SNMP SetRequest, but for the setup of the lock\n           to fail, and immediately thereafter be replaced by a lock\n           successfully set up by some other means; in such a case, the\n           value of t11FLockInitiatorType would change as and when the\n\n\n\n           lock was set up by the other means, and so the row could\n           not thereafter be deleted via t11FLockRowStatus.\n\n           FC-GS-5 mentions various error situations in which a\n           Fabric lock is released so as to avoid a deadlock.  In\n           such situations, the agent removes the corresponding row\n           in this table as and when the lock is released.  This can\n           happen for all values of t11FLockInitiatorType.")
t11FLockFabricIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 1), T11FabricIndex())
if mibBuilder.loadTexts: t11FLockFabricIndex.setDescription('A unique index value that uniquely identifies a\n           particular Fabric.\n\n           In a Fabric conformant to FC-SW-4, multiple Virtual Fabrics\n           can operate within one (or more) physical infrastructures,\n           and this index value is used to uniquely identify a\n\n\n\n           particular (physical or virtual) Fabric within a physical\n           infrastructure.\n\n           In a Fabric conformant to versions earlier than FC-SW-4,\n           only a single Fabric could operate within a physical\n           infrastructure, and thus, the value of this Fabric Index\n           was defined to always be 1.')
t11FLockApplicationID = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,1)).setFixedLength(1))
if mibBuilder.loadTexts: t11FLockApplicationID.setDescription("The Application_ID value that identifies the type of\n           application for which the Fabric is locked.\n\n           A lock established via Acquire Change Authorization (ACA)\n           does not, strictly speaking, have an Application_ID value.\n           However, the value 'FF'h (255 decimal) has been reserved\n           by T11 to be used as the value of this MIB object as and\n           when a lock is established by an ACA.  This value was\n           initially documented in a letter from the FC-SW-5 Editor\n           to T11.5, which was approved by the T11 and T11.5 plenary\n           meetings on October 5, 2006.")
t11FLockInitiatorType = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("ssb", 2), ("cli", 3), ("snmp", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FLockInitiatorType.setDescription('This object specifies what type of initiator generated\n           the request that caused this lock to be established:\n\n               other     - none of the following.\n\n\n\n               ssb       - this lock was established due to the\n                           receipt of an SSB, e.g., from a GS-5\n                           client.\n               cli       - this lock was established in order\n                           to process a Command Line Interface\n                           (CLI) command.\n               snmp      - this lock was established as a result\n                           of an SNMP SetRequest.\n           ')
t11FLockInitiator = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,64))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FLockInitiator.setDescription("This object specifies the initiator whose request\n           caused this lock to be established.\n\n           If the value of the corresponding instance\n           of t11FLockInitiatorType is 'ssb', this\n           object will contain the FC_ID of the client\n           that issued the Server Session Begin (SSB)\n           that required the lock to be established.\n\n           If the value of the corresponding instance\n           of t11FLockInitiatorType object is 'cli', this\n           object will contain the user name of the CLI\n           (Command Line Interface) user on whose behalf\n           the lock was established.\n\n           If the value of the corresponding instance of\n           t11FLockInitiatorType is 'snmp', this object\n           will contain the SNMP securityName used by the\n           SNMPv3 message containing the SetRequest that\n           created this row.  (If the row was created via\n           SNMPv1 or SNMPv2c, then the appropriate value of\n           the snmpCommunitySecurityName is used.)")
t11FLockInitiatorIpAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 5), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FLockInitiatorIpAddrType.setDescription("This object specifies the type of IP address contained\n           in the corresponding instance of t11FLockInitiatorIpAddr.\n           If the IP address of the location of the initiator is\n           unknown or not applicable, this object has the value:\n           'unknown'.")
t11FLockInitiatorIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 6), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FLockInitiatorIpAddr.setDescription("This object specifies the IP address of the location\n           of the initiator that established this lock via a\n           request of the type given by the corresponding instance\n           of t11FLockInitiatorType.  In cases where the\n           corresponding instance of t11FLockInitiatorIpAddrType has\n           the value: 'unknown', the value of this object is the\n           zero-length string.")
t11FLockStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("active", 1), ("settingUp", 2), ("rejectFailure", 3), ("otherFailure", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FLockStatus.setDescription("This object gives the current status of the lock:\n\n              'active'        -- the lock is currently established.\n              'settingUp'     -- the 'managing' switch is currently\n                                 attempting to set up the lock, e.g.,\n                                 it is waiting to receive Accepts\n                                 for ACAs from every switch in the\n                                 Fabric.\n\n\n\n              'rejectFailure' -- the 'managing' switch's attempt to\n                                 set up the lock was rejected with\n                                 the reason codes given by:\n                                    t11FLockRejectReasonCode,\n                                    t11FLockRejectReasonCodeExp and\n                                    t11FLockRejectReasonVendorCode.\n              'otherFailure'  -- the 'managing' switch's attempt\n                                 to set up the lock failed (but no\n                                 reason codes are available).\n\n           For values of t11FLockInitiatorType other than 'snmp',\n           a row is only required to be instantiated in this table\n           when the value of this object is 'active'.\n\n           If the value of the corresponding instance of\n           t11FLockInitiatorType is 'snmp', the initial value of this\n           object when the row is first created is 'settingUp'.  As\n           and when the setup succeeds, the value transitions to\n           'active'.  If the setup fails, the value transitions to\n           either 'rejectFailure' or 'otherFailure'.  Note that such a\n           failure value is overwritten on the next attempt to obtain\n           the lock, which could be immediately after the failure,\n           e.g., by a GS-5 client.\n\n           When the value of this object is 'rejectFailure', the\n           rejection's reason codes are given by the corresponding\n           values of t11FLockRejectReasonCode,\n           t11FLockRejectReasonCodeExp and\n           t11FLockRejectReasonVendorCode.")
t11FLockRejectReasonCode = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 8), T11NsGs4RejectReasonCode()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FLockRejectReasonCode.setDescription("When the value of the corresponding instance of\n           t11FLockStatus is 'rejectFailure', this object contains\n           the rejection's reason code.")
t11FLockRejectReasonCodeExp = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 9), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(1,1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FLockRejectReasonCodeExp.setDescription("When the value of the corresponding instance of\n           t11FLockStatus is 'rejectFailure', this object contains\n           the rejection's reason code explanation.")
t11FLockRejectReasonVendorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 10), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(1,1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FLockRejectReasonVendorCode.setDescription("When the value of the corresponding instance of\n           t11FLockStatus is 'rejectFailure', this object contains\n           the rejection's vendor-specific code.")
t11FLockRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 159, 1, 1, 1, 1, 11), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FLockRowStatus.setDescription("The status of this conceptual row.\n\n           A row in this table can be modified or deleted via\n           this object only when the row's value of\n           t11FLockInitiatorType is 'snmp'.")
t11FLockMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 159, 2, 1))
t11FLockMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 159, 2, 2))
t11FLockMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 159, 2, 1, 1)).setObjects(*(("T11-FC-FABRIC-LOCK-MIB", "t11FLockActiveGroup"),))
if mibBuilder.loadTexts: t11FLockMIBCompliance.setDescription('The compliance statement for entities that support\n           Fabric locks in support of GS-5 Server applications.')
t11FLockActiveGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 159, 2, 2, 1)).setObjects(*(("T11-FC-FABRIC-LOCK-MIB", "t11FLockInitiatorType"), ("T11-FC-FABRIC-LOCK-MIB", "t11FLockInitiator"), ("T11-FC-FABRIC-LOCK-MIB", "t11FLockInitiatorIpAddrType"), ("T11-FC-FABRIC-LOCK-MIB", "t11FLockInitiatorIpAddr"), ("T11-FC-FABRIC-LOCK-MIB", "t11FLockStatus"), ("T11-FC-FABRIC-LOCK-MIB", "t11FLockRejectReasonCode"), ("T11-FC-FABRIC-LOCK-MIB", "t11FLockRejectReasonCodeExp"), ("T11-FC-FABRIC-LOCK-MIB", "t11FLockRejectReasonVendorCode"), ("T11-FC-FABRIC-LOCK-MIB", "t11FLockRowStatus"),))
if mibBuilder.loadTexts: t11FLockActiveGroup.setDescription('A collection of objects containing information\n           about current Fabric locks.')
mibBuilder.exportSymbols("T11-FC-FABRIC-LOCK-MIB", t11FLockInitiatorIpAddrType=t11FLockInitiatorIpAddrType, t11FLockStatus=t11FLockStatus, t11FLockMIBNotifications=t11FLockMIBNotifications, t11FLockEntry=t11FLockEntry, t11FLockConfiguration=t11FLockConfiguration, t11FLockInitiatorType=t11FLockInitiatorType, t11FLockMIBCompliances=t11FLockMIBCompliances, t11FLockApplicationID=t11FLockApplicationID, t11FLockMIBConformance=t11FLockMIBConformance, t11FLockMIBCompliance=t11FLockMIBCompliance, t11FLockActiveGroup=t11FLockActiveGroup, t11FLockInitiatorIpAddr=t11FLockInitiatorIpAddr, t11FLockTable=t11FLockTable, t11FLockRejectReasonCode=t11FLockRejectReasonCode, t11FLockRejectReasonVendorCode=t11FLockRejectReasonVendorCode, t11FLockInitiator=t11FLockInitiator, PYSNMP_MODULE_ID=t11FabricLockMIB, t11FLockRowStatus=t11FLockRowStatus, t11FLockMIBGroups=t11FLockMIBGroups, t11FLockRejectReasonCodeExp=t11FLockRejectReasonCodeExp, t11FLockMIBObjects=t11FLockMIBObjects, t11FabricLockMIB=t11FabricLockMIB, t11FLockFabricIndex=t11FLockFabricIndex)



#
# PySNMP MIB module ITU-ALARM-TC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ITU-ALARM-TC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:19:29 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ConstraintsUnion", "ValueRangeConstraint")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( MibScalar, MibTable, MibTableRow, MibTableColumn, ObjectIdentity, Counter64, Gauge32, IpAddress, NotificationType, Unsigned32, ModuleIdentity, MibIdentifier, Bits, TimeTicks, mib_2, iso, Integer32, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ObjectIdentity", "Counter64", "Gauge32", "IpAddress", "NotificationType", "Unsigned32", "ModuleIdentity", "MibIdentifier", "Bits", "TimeTicks", "mib-2", "iso", "Integer32", "Counter32")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
ituAlarmTc = ModuleIdentity((1, 3, 6, 1, 2, 1, 120)).setRevisions(("2004-09-09 00:00",))
if mibBuilder.loadTexts: ituAlarmTc.setLastUpdated('200409090000Z')
if mibBuilder.loadTexts: ituAlarmTc.setOrganization('IETF Distributed Management Working Group')
if mibBuilder.loadTexts: ituAlarmTc.setContactInfo(' WG EMail: disman@ietf.org\n           Subscribe: disman-request@ietf.org\n           http://www.ietf.org/html.charters/disman-charter.html\n\n           Chair:     Randy Presuhn\n                      randy_presuhn@mindspring.com\n\n           Editors:   Sharon Chisholm\n                      Nortel Networks\n                      PO Box 3511 Station C\n                      Ottawa, Ont.  K1Y 4H7\n                      Canada\n                      schishol@nortelnetworks.com\n\n                      Dan Romascanu\n                      Avaya\n                      Atidim Technology Park, Bldg. #3\n                      Tel Aviv, 61131\n                      Israel\n                      Tel: +972-3-645-8414\n                      Email: dromasca@avaya.com')
if mibBuilder.loadTexts: ituAlarmTc.setDescription('This MIB module defines the ITU Alarm\n         textual convention for objects not expected to require\n         regular extension.\n\n         Copyright (C) The Internet Society (2004).  The\n         initial version of this MIB module was published\n         in RFC 3877.  For full legal notices see the RFC\n         itself.  Supplementary information may be available on:\n         http://www.ietf.org/copyrights/ianamib.html')
class ItuPerceivedSeverity(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))
    namedValues = NamedValues(("cleared", 1), ("indeterminate", 2), ("critical", 3), ("major", 4), ("minor", 5), ("warning", 6),)

class ItuTrendIndication(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("moreSevere", 1), ("noChange", 2), ("lessSevere", 3),)

mibBuilder.exportSymbols("ITU-ALARM-TC-MIB", ItuPerceivedSeverity=ItuPerceivedSeverity, ituAlarmTc=ituAlarmTc, PYSNMP_MODULE_ID=ituAlarmTc, ItuTrendIndication=ItuTrendIndication)



#
# PySNMP MIB module TE-LINK-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/TE-LINK-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:19:51 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ValueSizeConstraint, ConstraintsIntersection, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "ValueRangeConstraint")
( InterfaceIndexOrZero, ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero", "ifIndex")
( InetAddressType, InetAddress, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressType", "InetAddress")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( MibScalar, MibTable, MibTableRow, MibTableColumn, iso, Unsigned32, ModuleIdentity, Bits, Counter32, Counter64, ObjectIdentity, transmission, TimeTicks, NotificationType, Gauge32, MibIdentifier, IpAddress, Integer32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "iso", "Unsigned32", "ModuleIdentity", "Bits", "Counter32", "Counter64", "ObjectIdentity", "transmission", "TimeTicks", "NotificationType", "Gauge32", "MibIdentifier", "IpAddress", "Integer32")
( RowStatus, DisplayString, TextualConvention, StorageType, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "DisplayString", "TextualConvention", "StorageType")
teLinkStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 200)).setRevisions(("2005-10-11 00:00",))
if mibBuilder.loadTexts: teLinkStdMIB.setLastUpdated('200510110000Z')
if mibBuilder.loadTexts: teLinkStdMIB.setOrganization('Multiprotocol Label Switching (MPLS) Working Group')
if mibBuilder.loadTexts: teLinkStdMIB.setContactInfo('        Martin Dubuc\n        Email:  mdubuc@ncf.ca\n\n                Thomas D. Nadeau\n        Email:  tnadeau@cisco.com\n\n\n\n\n                Jonathan P. Lang\n        Email:  jplang@ieee.org\n\n        Comments about this document should be emailed directly to\n        the MPLS working group mailing list at mpls@uu.net.')
if mibBuilder.loadTexts: teLinkStdMIB.setDescription("Copyright (C) 2005 The Internet Society.  This version of\n        this MIB module is part of RFC 4220; see the RFC\n        itself for full legal notices.\n\n        This MIB module contains managed object definitions for\n        MPLS traffic engineering links as defined in\n        'Link Bundling in MPLS Traffic Engineering (TE)'.")
class TeLinkBandwidth(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(4,4)
    fixedLength = 4

class TeLinkPriority(Unsigned32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,7)

class TeLinkProtection(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("primary", 1), ("secondary", 2),)

class TeLinkSwitchingCapability(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 51, 100, 150, 200,))
    namedValues = NamedValues(("packetSwitch1", 1), ("packetSwitch2", 2), ("packetSwitch3", 3), ("packetSwitch4", 4), ("layer2Switch", 51), ("tdm", 100), ("lambdaSwitch", 150), ("fiberSwitch", 200),)

class TeLinkEncodingType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 5, 7, 8, 9, 11,))
    namedValues = NamedValues(("packet", 1), ("ethernet", 2), ("ansiEtsiPdh", 3), ("sdhItuSonetAnsi", 5), ("digitalWrapper", 7), ("lambda", 8), ("fiber", 9), ("fiberChannel", 11),)

class TeLinkSonetSdhIndication(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1,))
    namedValues = NamedValues(("standard", 0), ("arbitrary", 1),)

teLinkNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 200, 0))
teLinkObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 200, 1))
teLinkConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 200, 2))
teLinkTable = MibTable((1, 3, 6, 1, 2, 1, 10, 200, 1, 1), )
if mibBuilder.loadTexts: teLinkTable.setDescription('This table specifies the grouping of component links into\n        TE links and the grouping of TE links into bundled links.')
teLinkEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: teLinkEntry.setDescription('An entry in this table exists for each ifEntry with an\n        ifType of teLink(200), i.e., for every TE link.  An ifEntry\n        in the ifTable must exist before a teLinkEntry is created\n        with the corresponding ifIndex.  If a TE link entry in the\n        ifTable is destroyed, then so is the corresponding entry\n        in the teLinkTable.  The administrative and operational\n        status values are controlled from the ifEntry.')
teLinkAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 1), InetAddressType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkAddressType.setDescription('The type of Internet address for the TE link.')
teLinkLocalIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 2), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkLocalIpAddr.setDescription('The local Internet address for numbered links.  The type of\n        this address is determined by the value of the\n        teLinkAddressType object.\n\n        For IPv4 and IPv6 numbered links, this object represents the\n        local IP address associated with the TE link.  For an\n        unnumbered link, the local address is of type unknown, this\n        object is set to the zero length string, and the\n        teLinkOutgoingIfId object then identifies the unnumbered\n        address.\n\n        If the TE link is a Forwarding Adjacency (FA), the local\n        IP address is set to the head-end address of the FA-LSP.\n\n        If ipAddrTable is implemented, this object must have the\n        same value as the ipAdEntAddr object that belongs to the\n        row in ipAddrTable where ipAdEntIfIndex is equal to\n\n\n\n        ifIndex.')
teLinkRemoteIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 3), InetAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkRemoteIpAddr.setDescription('The remote Internet address for numbered links.  The type of\n        this address is determined by the value of the\n        teLinkAddressType object.\n\n        The remote IP address associated with the TE link (IPv4 and\n        IPv6 numbered links).  For an unnumbered link, the remote\n        address is of type unknown, this object is set to the\n        zero length string, and the teLinkIncomingIfId object then\n        identifies the unnumbered address.\n\n        If the TE link is a Forwarding Adjacency, the remote IP\n        address is set to the tail-end address of the FA-LSP.')
teLinkMetric = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 4), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkMetric.setDescription('The traffic engineering metric for the TE link is\n        derived from its component links.  All component links\n        within the TE link must have the same traffic\n        engineering metric.')
teLinkMaximumReservableBandwidth = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 5), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readonly")
if mibBuilder.loadTexts: teLinkMaximumReservableBandwidth.setDescription('This attribute specifies the maximum reservable bandwidth on\n        the TE link.  This is the union of the maximum reservable\n        bandwidth of all the component links within the\n        TE link that can be used to carry live traffic.')
teLinkProtectionType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("extraTraffic", 1), ("unprotected", 2), ("shared", 3), ("dedicated1For1", 4), ("dedicated1Plus1", 5), ("enhanced", 6),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkProtectionType.setDescription("This attribute specifies the link protection type of the\n        TE link.  Descriptions of the different protection types can\n        be found in the 'Routing Extensions in Support of\n        Generalized Multi-Protocol Label Switching (GMPLS)'\n        document.")
teLinkWorkingPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 7), TeLinkPriority()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkWorkingPriority.setDescription('This object represents a priority value such that a new\n        connection with a higher priority, i.e., numerically lower\n        than this value, is guaranteed to be setup on a primary\n        link and not on a secondary link.')
teLinkResourceClass = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 8), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkResourceClass.setDescription("This attribute specifies the TE link resource class.\n        The resource class is a 32 bit bitfield.  The resource class\n        for a link bundle is derived from the resource class of its\n\n\n\n        TE links.  All TE links within a link bundle must have the\n        same resource class.  Encoding of the resource class is\n        described in the 'Traffic Engineering (TE) Extensions to\n        OSPF Version 2' document.")
teLinkIncomingIfId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkIncomingIfId.setDescription('For unnumbered links, the incoming interface is set to the\n        outgoing interface identifier chosen by the neighboring LSR\n        for the reverse link corresponding to this TE link.  If the\n        link is numbered, the value of this object is 0 and the\n        address is stored in the teLinkRemoteIpAddr instead.')
teLinkOutgoingIfId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 10), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkOutgoingIfId.setDescription('If the link is unnumbered, the outgoing interface identifier\n        is set to the outgoing interface identifier chosen for the\n        TE link by the advertising LSR.  If the link is numbered, the\n        value of this object is 0 and the address is stored in the\n        teLinkLocalIpAddr instead.')
teLinkRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 11), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  None of the writable objects in\n        a row can be changed if status is active(1).')
teLinkStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 1, 1, 12), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkStorageType.setDescription("The storage type for this conceptual row in the\n        teLinkTable.  Conceptual rows having the value\n        'permanent' need not allow write-access to any\n        columnar object in the row.")
teLinkDescriptorTable = MibTable((1, 3, 6, 1, 2, 1, 10, 200, 1, 2), )
if mibBuilder.loadTexts: teLinkDescriptorTable.setDescription('This table specifies the interface switching capability\n        descriptors associated with the TE links.')
teLinkDescriptorEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "TE-LINK-STD-MIB", "teLinkDescriptorId"))
if mibBuilder.loadTexts: teLinkDescriptorEntry.setDescription('An entry in this table is created for every TE link interface\n        switching capability descriptor.  An ifEntry in the ifTable\n        must exist before a teLinkDescriptorEntry using the same\n        ifIndex is created.  ifType of ifEntry must be teLink(200).\n        If a TE link entry in the ifTable is destroyed, then so are\n        all of the entries in the teLinkDescriptorTable that use the\n        ifIndex of this TE link.')
teLinkDescriptorId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: teLinkDescriptorId.setDescription('This object specifies the link descriptor identifier.')
teLinkDescrSwitchingCapability = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 2), TeLinkSwitchingCapability()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrSwitchingCapability.setDescription('This attribute specifies interface switching capability of\n        the TE link, which is derived from its component links.')
teLinkDescrEncodingType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 3), TeLinkEncodingType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrEncodingType.setDescription('This attribute specifies the TE link encoding type.')
teLinkDescrMinLspBandwidth = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 4), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrMinLspBandwidth.setDescription('This attribute specifies the minimum LSP bandwidth on\n        the TE link.  This is derived from the union of the\n        minimum LSP bandwidth of all the component links\n        associated with the TE link that can be used to carry\n        live traffic.')
teLinkDescrMaxLspBandwidthPrio0 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 5), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrMaxLspBandwidthPrio0.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 0 on the TE link.  This is the union of the maximum\n        LSP bandwidth at priority 0 of all the component links within\n        the TE link that can be used to carry live traffic.')
teLinkDescrMaxLspBandwidthPrio1 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 6), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrMaxLspBandwidthPrio1.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 1 on the TE link.  This is the union of the maximum\n        LSP bandwidth at priority 1 of all the component links within\n        the TE link that can be used to carry live traffic.')
teLinkDescrMaxLspBandwidthPrio2 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 7), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrMaxLspBandwidthPrio2.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 2 on the TE link.  This is the union of the maximum\n\n\n\n        LSP bandwidth at priority 2 of all the component links within\n        the TE link that can be used to carry live traffic.')
teLinkDescrMaxLspBandwidthPrio3 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 8), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrMaxLspBandwidthPrio3.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 3 on the TE link.  This is the union of the maximum\n        LSP bandwidth at priority 3 of all the component links within\n        the TE link that can be used to carry live traffic.')
teLinkDescrMaxLspBandwidthPrio4 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 9), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrMaxLspBandwidthPrio4.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 4 on the TE link.  This is the union of the maximum\n        LSP bandwidth at priority 4 of all the component links within\n        the TE link that can be used to carry live traffic.')
teLinkDescrMaxLspBandwidthPrio5 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 10), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrMaxLspBandwidthPrio5.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 5 on the TE link.  This is the union of the maximum\n        LSP bandwidth at priority 5 of all the component links within\n        the TE link that can be used to carry live traffic.')
teLinkDescrMaxLspBandwidthPrio6 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 11), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrMaxLspBandwidthPrio6.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 6 on the TE link.  This is the union of the maximum\n        LSP bandwidth at priority 6 of all the component links within\n        the TE link that can be used to carry live traffic.')
teLinkDescrMaxLspBandwidthPrio7 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 12), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrMaxLspBandwidthPrio7.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 7 on the TE link.  This is the union of the maximum\n        LSP bandwidth at priority 7 of all the component links within\n        the TE link that can be used to carry live traffic.')
teLinkDescrInterfaceMtu = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 13), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrInterfaceMtu.setDescription('This attribute specifies the interface MTU for the TE\n        link descriptor.')
teLinkDescrIndication = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 14), TeLinkSonetSdhIndication()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrIndication.setDescription('This attribute specifies whether this interface supports\n        Standard or Arbitrary SONET/SDH.')
teLinkDescrRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 15), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  No read-create object\n        can be changed if teLinkDescrRowStatus is in the active(1)\n        state.')
teLinkDescrStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 2, 1, 16), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkDescrStorageType.setDescription("The storage type for this conceptual row in the\n        teLinkDescriptorTable.  Conceptual rows having the value\n        'permanent' need not allow write-access to any\n        columnar object in the row.")
teLinkSrlgTable = MibTable((1, 3, 6, 1, 2, 1, 10, 200, 1, 3), )
if mibBuilder.loadTexts: teLinkSrlgTable.setDescription('This table specifies the SRLGs associated with TE links.')
teLinkSrlgEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 200, 1, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "TE-LINK-STD-MIB", "teLinkSrlg"))
if mibBuilder.loadTexts: teLinkSrlgEntry.setDescription('An entry in this table contains information about an\n        SRLG associated with a TE link.\n        An ifEntry in the ifTable must exist before a\n        teLinkSrlgEntry using the same ifIndex is created.\n        The ifType of ifEntry must be teLink(200).\n        If a TE link entry in the ifTable is destroyed, then so\n        are all of the entries in the teLinkSrlgTable that use the\n        ifIndex of this TE link.')
teLinkSrlg = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 3, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295)))
if mibBuilder.loadTexts: teLinkSrlg.setDescription('This identifies an SRLG supported by the TE link.  An SRLG is\n        identified with a 32-bit number that is unique within an IGP\n        domain.  Zero is a valid SRLG number.')
teLinkSrlgRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 3, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkSrlgRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  No read-create object can\n        be modified if teLinkSrlgRowStatus is active(1).')
teLinkSrlgStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 3, 1, 3), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkSrlgStorageType.setDescription("The storage type for this conceptual row in the\n\n\n\n        teLinkSrlgTable.  Conceptual rows having the value\n        'permanent' need not allow write-access to any\n        columnar object in the row.")
teLinkBandwidthTable = MibTable((1, 3, 6, 1, 2, 1, 10, 200, 1, 4), )
if mibBuilder.loadTexts: teLinkBandwidthTable.setDescription('This table specifies the priority-based bandwidth table\n        for TE links.')
teLinkBandwidthEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 200, 1, 4, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "TE-LINK-STD-MIB", "teLinkBandwidthPriority"))
if mibBuilder.loadTexts: teLinkBandwidthEntry.setDescription('An entry in this table contains information about\n        the priority-based bandwidth of TE links.  An ifEntry in the\n        ifTable must exist before a teLinkBandwidthEntry using the\n        same ifIndex is created.  The ifType of ifEntry must be\n        teLink(200).  If a TE link entry in the ifTable is destroyed,\n        then so are all of the entries in the teLinkBandwidthTable\n        that use the ifIndex of this TE link.')
teLinkBandwidthPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 4, 1, 1), TeLinkPriority())
if mibBuilder.loadTexts: teLinkBandwidthPriority.setDescription("This attribute specifies the priority.  A value of 0 is valid\n        as specified in the 'Traffic Engineering (TE) Extensions to\n\n\n\n        OSPF Version 2' document.")
teLinkBandwidthUnreserved = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 4, 1, 2), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readonly")
if mibBuilder.loadTexts: teLinkBandwidthUnreserved.setDescription('This attribute specifies the TE link unreserved\n        bandwidth at priority p.  It is the sum of the unreserved\n        bandwidths at priority p of all component links associated\n        with the TE link (excluding all links that are strictly\n        used as protecting links).')
teLinkBandwidthRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 4, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkBandwidthRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  No read-create object\n        can be modified when teLinkBandwidthRowStatus is active(1).')
teLinkBandwidthStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 4, 1, 4), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: teLinkBandwidthStorageType.setDescription("The storage type for this conceptual row in the\n        teLinkBandwidthTable.  Conceptual rows having the value\n        'permanent' need not allow write-access to any\n        columnar object in the row.")
componentLinkTable = MibTable((1, 3, 6, 1, 2, 1, 10, 200, 1, 5), )
if mibBuilder.loadTexts: componentLinkTable.setDescription('This table specifies the component link parameters.')
componentLinkEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 200, 1, 5, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: componentLinkEntry.setDescription("An entry in this table exists for each ifEntry that\n        represents a component link.  An ifEntry must exist in\n        the ifTable before a componentLinkEntry is created with\n        the corresponding ifIndex.  ifEntry's ifType can be\n        of any interface type that has been defined for TE Link\n        interworking.  Examples include ATM, Frame Relay, Ethernet,\n        etc.  If an entry representing a component link is destroyed\n        in the ifTable, then so is the corresponding entry in the\n        componentLinkTable.  The administrative and operational\n        status values are controlled from the ifEntry.")
componentLinkMaxResBandwidth = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 5, 1, 1), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkMaxResBandwidth.setDescription('This attribute specifies the maximum reservable bandwidth on\n        the component link.')
componentLinkPreferredProtection = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 5, 1, 2), TeLinkProtection()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkPreferredProtection.setDescription('This attribute specifies whether this component link is\n        a primary or secondary entity.')
componentLinkCurrentProtection = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 5, 1, 3), TeLinkProtection()).setMaxAccess("readonly")
if mibBuilder.loadTexts: componentLinkCurrentProtection.setDescription('This attribute specifies whether this component link is\n        currently used as primary or secondary link.')
componentLinkRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 5, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  No read-create object\n        can be modified when componentLinkRowStatus is active(1).')
componentLinkStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 5, 1, 5), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkStorageType.setDescription("The storage type for this conceptual row in the\n        componentLinkTable.  Conceptual rows having the value\n        'permanent' need not allow write-access to any\n        columnar object in the row.")
componentLinkDescriptorTable = MibTable((1, 3, 6, 1, 2, 1, 10, 200, 1, 6), )
if mibBuilder.loadTexts: componentLinkDescriptorTable.setDescription('This table specifies the interface switching capability\n        descriptors associated with the component links.')
componentLinkDescriptorEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "TE-LINK-STD-MIB", "componentLinkDescrId"))
if mibBuilder.loadTexts: componentLinkDescriptorEntry.setDescription("An entry in this table is created for every component link\n        descriptor.  An ifEntry in the ifTable must exist before a\n        componentLinkDescriptorEntry using the same ifIndex is\n        created.  ifEntry's ifType can be of any interface type that\n        has been defined for TE Link interworking.  Examples include\n        ATM, Frame Relay, Ethernet, etc.  If a component link entry\n        in the ifTable is destroyed, then so are all entries in the\n        componentLinkDescriptorTable that use the ifIndex of this\n        component link.")
componentLinkDescrId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: componentLinkDescrId.setDescription('This object specifies the link descriptor identifier.')
componentLinkDescrSwitchingCapability = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 2), TeLinkSwitchingCapability()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrSwitchingCapability.setDescription('This attribute specifies link multiplexing capabilities of\n        the component link.')
componentLinkDescrEncodingType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 3), TeLinkEncodingType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrEncodingType.setDescription('This attribute specifies the component link encoding type.')
componentLinkDescrMinLspBandwidth = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 4), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrMinLspBandwidth.setDescription('This attribute specifies the minimum LSP bandwidth on\n        the component link.')
componentLinkDescrMaxLspBandwidthPrio0 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 5), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrMaxLspBandwidthPrio0.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 0 on the component link.')
componentLinkDescrMaxLspBandwidthPrio1 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 6), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrMaxLspBandwidthPrio1.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 1 on the component link.')
componentLinkDescrMaxLspBandwidthPrio2 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 7), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrMaxLspBandwidthPrio2.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 2 on the component link.')
componentLinkDescrMaxLspBandwidthPrio3 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 8), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrMaxLspBandwidthPrio3.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 3 on the component link.')
componentLinkDescrMaxLspBandwidthPrio4 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 9), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrMaxLspBandwidthPrio4.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 4 on the component link.')
componentLinkDescrMaxLspBandwidthPrio5 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 10), TeLinkBandwidth()).setUnits('thousand bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrMaxLspBandwidthPrio5.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 5 on the component link.')
componentLinkDescrMaxLspBandwidthPrio6 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 11), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrMaxLspBandwidthPrio6.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 6 on the component link.')
componentLinkDescrMaxLspBandwidthPrio7 = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 12), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrMaxLspBandwidthPrio7.setDescription('This attribute specifies the maximum LSP bandwidth at\n        priority 7 on the component link.')
componentLinkDescrInterfaceMtu = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 13), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrInterfaceMtu.setDescription('This attribute specifies the interface MTU for the component\n        link descriptor.')
componentLinkDescrIndication = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 14), TeLinkSonetSdhIndication()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrIndication.setDescription('This attribute specifies whether this interface supports\n        Standard or Arbitrary SONET/SDH.')
componentLinkDescrRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 15), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  No read-create object\n        can be modified when componentLinkDescrRowStatus\n        is active(1).')
componentLinkDescrStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 6, 1, 16), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkDescrStorageType.setDescription("The storage type for this conceptual row in the\n        componentLinkDescriptorTable.  Conceptual rows\n        having the value 'permanent' need not allow write-access\n        to any columnar object in the row.")
componentLinkBandwidthTable = MibTable((1, 3, 6, 1, 2, 1, 10, 200, 1, 7), )
if mibBuilder.loadTexts: componentLinkBandwidthTable.setDescription('This table specifies the priority-based bandwidth\n        for component links.')
componentLinkBandwidthEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 200, 1, 7, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "TE-LINK-STD-MIB", "componentLinkBandwidthPriority"))
if mibBuilder.loadTexts: componentLinkBandwidthEntry.setDescription("An entry in this table contains information about\n        the priority-based bandwidth on component links.\n        An ifEntry in the ifTable must exist before a\n        componentLinkBandwidthEntry using the same ifIndex is\n        created.  ifEntry's ifType can be of any interface type that\n        has been defined for TE Link interworking.  Examples\n        include ATM, Frame Relay, Ethernet, etc.  If a component link\n        entry in the ifTable is destroyed, then so are all entries\n        in the componentLinkBandwidthTable that use the ifIndex of\n        this component link.")
componentLinkBandwidthPriority = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 7, 1, 1), TeLinkPriority())
if mibBuilder.loadTexts: componentLinkBandwidthPriority.setDescription("This attribute specifies the priority.  A value of 0 is valid\n        as specified in the 'Traffic Engineering (TE) Extensions to\n         OSPF Version 2' document.")
componentLinkBandwidthUnreserved = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 7, 1, 2), TeLinkBandwidth()).setUnits('bps').setMaxAccess("readonly")
if mibBuilder.loadTexts: componentLinkBandwidthUnreserved.setDescription('This attribute specifies the component link unreserved\n        bandwidth at priority p.')
componentLinkBandwidthRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 7, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkBandwidthRowStatus.setDescription('This variable is used to create, modify, and/or\n        delete a row in this table.  No read-create object can\n        be modified when componentLinkBandwidthRowStatus is\n        active(1).')
componentLinkBandwidthStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 200, 1, 7, 1, 4), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: componentLinkBandwidthStorageType.setDescription("The storage type for this conceptual row in the\n        componentLinkBandwidthTable.  Conceptual rows\n        having the value 'permanent' need not allow write-access\n        to any columnar object in the row.")
teLinkCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 200, 2, 1))
teLinkGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 200, 2, 2))
teLinkModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 200, 2, 1, 1)).setObjects(*(("TE-LINK-STD-MIB", "teLinkGroup"), ("TE-LINK-STD-MIB", "teLinkBandwidthGroup"), ("TE-LINK-STD-MIB", "componentLinkBandwidthGroup"), ("TE-LINK-STD-MIB", "teLinkSrlgGroup"), ("TE-LINK-STD-MIB", "teLinkPscGroup"), ("TE-LINK-STD-MIB", "teLinkTdmGroup"),))
if mibBuilder.loadTexts: teLinkModuleFullCompliance.setDescription('Compliance statement for agents that support read-create\n        so that both configuration and monitoring of TE links can\n        be accomplished via this MIB module.')
teLinkModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 200, 2, 1, 2)).setObjects(*(("TE-LINK-STD-MIB", "teLinkGroup"), ("TE-LINK-STD-MIB", "teLinkBandwidthGroup"), ("TE-LINK-STD-MIB", "componentLinkBandwidthGroup"), ("TE-LINK-STD-MIB", "teLinkSrlgGroup"), ("TE-LINK-STD-MIB", "teLinkPscGroup"), ("TE-LINK-STD-MIB", "teLinkTdmGroup"),))
if mibBuilder.loadTexts: teLinkModuleReadOnlyCompliance.setDescription('Compliance statement for agents that support the\n        monitoring of the TE link MIB module.')
teLinkGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 200, 2, 2, 1)).setObjects(*(("TE-LINK-STD-MIB", "teLinkAddressType"), ("TE-LINK-STD-MIB", "teLinkLocalIpAddr"), ("TE-LINK-STD-MIB", "teLinkRemoteIpAddr"), ("TE-LINK-STD-MIB", "teLinkMetric"), ("TE-LINK-STD-MIB", "teLinkProtectionType"), ("TE-LINK-STD-MIB", "teLinkWorkingPriority"), ("TE-LINK-STD-MIB", "teLinkResourceClass"), ("TE-LINK-STD-MIB", "teLinkIncomingIfId"), ("TE-LINK-STD-MIB", "teLinkOutgoingIfId"), ("TE-LINK-STD-MIB", "teLinkRowStatus"), ("TE-LINK-STD-MIB", "teLinkStorageType"), ("TE-LINK-STD-MIB", "teLinkDescrSwitchingCapability"), ("TE-LINK-STD-MIB", "teLinkDescrEncodingType"), ("TE-LINK-STD-MIB", "teLinkDescrRowStatus"), ("TE-LINK-STD-MIB", "teLinkDescrStorageType"), ("TE-LINK-STD-MIB", "componentLinkPreferredProtection"), ("TE-LINK-STD-MIB", "componentLinkCurrentProtection"), ("TE-LINK-STD-MIB", "componentLinkRowStatus"), ("TE-LINK-STD-MIB", "componentLinkStorageType"), ("TE-LINK-STD-MIB", "componentLinkDescrSwitchingCapability"), ("TE-LINK-STD-MIB", "componentLinkDescrEncodingType"), ("TE-LINK-STD-MIB", "componentLinkDescrRowStatus"), ("TE-LINK-STD-MIB", "componentLinkDescrStorageType"),))
if mibBuilder.loadTexts: teLinkGroup.setDescription('Collection of objects needed for the management of\n           resources associated with TE links.')
teLinkSrlgGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 200, 2, 2, 2)).setObjects(*(("TE-LINK-STD-MIB", "teLinkSrlgRowStatus"), ("TE-LINK-STD-MIB", "teLinkSrlgStorageType"),))
if mibBuilder.loadTexts: teLinkSrlgGroup.setDescription('Collection of objects needed for the management of\n           SRLG resources associated with TE links.')
teLinkBandwidthGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 200, 2, 2, 3)).setObjects(*(("TE-LINK-STD-MIB", "teLinkMaximumReservableBandwidth"), ("TE-LINK-STD-MIB", "teLinkDescrMaxLspBandwidthPrio0"), ("TE-LINK-STD-MIB", "teLinkDescrMaxLspBandwidthPrio1"), ("TE-LINK-STD-MIB", "teLinkDescrMaxLspBandwidthPrio2"), ("TE-LINK-STD-MIB", "teLinkDescrMaxLspBandwidthPrio3"), ("TE-LINK-STD-MIB", "teLinkDescrMaxLspBandwidthPrio4"), ("TE-LINK-STD-MIB", "teLinkDescrMaxLspBandwidthPrio5"), ("TE-LINK-STD-MIB", "teLinkDescrMaxLspBandwidthPrio6"), ("TE-LINK-STD-MIB", "teLinkDescrMaxLspBandwidthPrio7"), ("TE-LINK-STD-MIB", "teLinkBandwidthUnreserved"), ("TE-LINK-STD-MIB", "teLinkBandwidthRowStatus"), ("TE-LINK-STD-MIB", "teLinkBandwidthStorageType"),))
if mibBuilder.loadTexts: teLinkBandwidthGroup.setDescription('Collection of objects needed for the management of\n           the bandwidth resources associated with TE links and\n           component links.')
componentLinkBandwidthGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 200, 2, 2, 4)).setObjects(*(("TE-LINK-STD-MIB", "componentLinkMaxResBandwidth"), ("TE-LINK-STD-MIB", "componentLinkDescrMaxLspBandwidthPrio0"), ("TE-LINK-STD-MIB", "componentLinkDescrMaxLspBandwidthPrio1"), ("TE-LINK-STD-MIB", "componentLinkDescrMaxLspBandwidthPrio2"), ("TE-LINK-STD-MIB", "componentLinkDescrMaxLspBandwidthPrio3"), ("TE-LINK-STD-MIB", "componentLinkDescrMaxLspBandwidthPrio4"), ("TE-LINK-STD-MIB", "componentLinkDescrMaxLspBandwidthPrio5"), ("TE-LINK-STD-MIB", "componentLinkDescrMaxLspBandwidthPrio6"), ("TE-LINK-STD-MIB", "componentLinkDescrMaxLspBandwidthPrio7"), ("TE-LINK-STD-MIB", "componentLinkBandwidthUnreserved"), ("TE-LINK-STD-MIB", "componentLinkBandwidthRowStatus"), ("TE-LINK-STD-MIB", "componentLinkBandwidthStorageType"),))
if mibBuilder.loadTexts: componentLinkBandwidthGroup.setDescription('Collection of objects needed for the management of the\n           bandwidth parameters associated with component links.')
teLinkPscGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 200, 2, 2, 5)).setObjects(*(("TE-LINK-STD-MIB", "teLinkDescrMinLspBandwidth"), ("TE-LINK-STD-MIB", "teLinkDescrInterfaceMtu"), ("TE-LINK-STD-MIB", "componentLinkDescrMinLspBandwidth"), ("TE-LINK-STD-MIB", "componentLinkDescrInterfaceMtu"),))
if mibBuilder.loadTexts: teLinkPscGroup.setDescription('Collection of objects needed for devices that are\n           packet switch capable.')
teLinkTdmGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 200, 2, 2, 6)).setObjects(*(("TE-LINK-STD-MIB", "teLinkDescrMinLspBandwidth"), ("TE-LINK-STD-MIB", "teLinkDescrIndication"), ("TE-LINK-STD-MIB", "componentLinkDescrMinLspBandwidth"), ("TE-LINK-STD-MIB", "componentLinkDescrIndication"),))
if mibBuilder.loadTexts: teLinkTdmGroup.setDescription('Collection of objects needed for devices that are\n           TDM switching capable.')
mibBuilder.exportSymbols("TE-LINK-STD-MIB", teLinkSrlgRowStatus=teLinkSrlgRowStatus, componentLinkBandwidthRowStatus=componentLinkBandwidthRowStatus, teLinkDescrMinLspBandwidth=teLinkDescrMinLspBandwidth, componentLinkDescrMaxLspBandwidthPrio5=componentLinkDescrMaxLspBandwidthPrio5, teLinkStdMIB=teLinkStdMIB, teLinkTdmGroup=teLinkTdmGroup, teLinkSrlgEntry=teLinkSrlgEntry, componentLinkEntry=componentLinkEntry, componentLinkDescrMaxLspBandwidthPrio2=componentLinkDescrMaxLspBandwidthPrio2, TeLinkSonetSdhIndication=TeLinkSonetSdhIndication, componentLinkDescrSwitchingCapability=componentLinkDescrSwitchingCapability, componentLinkDescrMaxLspBandwidthPrio0=componentLinkDescrMaxLspBandwidthPrio0, TeLinkProtection=TeLinkProtection, componentLinkDescrMaxLspBandwidthPrio1=componentLinkDescrMaxLspBandwidthPrio1, teLinkAddressType=teLinkAddressType, teLinkResourceClass=teLinkResourceClass, teLinkBandwidthPriority=teLinkBandwidthPriority, componentLinkDescrEncodingType=componentLinkDescrEncodingType, teLinkTable=teLinkTable, teLinkLocalIpAddr=teLinkLocalIpAddr, teLinkDescrStorageType=teLinkDescrStorageType, teLinkNotifications=teLinkNotifications, teLinkCompliances=teLinkCompliances, teLinkProtectionType=teLinkProtectionType, teLinkBandwidthEntry=teLinkBandwidthEntry, teLinkMaximumReservableBandwidth=teLinkMaximumReservableBandwidth, teLinkDescrMaxLspBandwidthPrio3=teLinkDescrMaxLspBandwidthPrio3, componentLinkBandwidthUnreserved=componentLinkBandwidthUnreserved, teLinkDescrIndication=teLinkDescrIndication, teLinkDescrMaxLspBandwidthPrio4=teLinkDescrMaxLspBandwidthPrio4, teLinkConformance=teLinkConformance, componentLinkBandwidthGroup=componentLinkBandwidthGroup, componentLinkDescrId=componentLinkDescrId, teLinkSrlgGroup=teLinkSrlgGroup, componentLinkDescrMaxLspBandwidthPrio6=componentLinkDescrMaxLspBandwidthPrio6, teLinkDescrSwitchingCapability=teLinkDescrSwitchingCapability, componentLinkDescrMaxLspBandwidthPrio4=componentLinkDescrMaxLspBandwidthPrio4, componentLinkMaxResBandwidth=componentLinkMaxResBandwidth, componentLinkBandwidthStorageType=componentLinkBandwidthStorageType, componentLinkDescrRowStatus=componentLinkDescrRowStatus, TeLinkPriority=TeLinkPriority, teLinkDescrRowStatus=teLinkDescrRowStatus, teLinkBandwidthUnreserved=teLinkBandwidthUnreserved, teLinkGroup=teLinkGroup, teLinkGroups=teLinkGroups, teLinkDescrInterfaceMtu=teLinkDescrInterfaceMtu, teLinkPscGroup=teLinkPscGroup, teLinkOutgoingIfId=teLinkOutgoingIfId, componentLinkBandwidthEntry=componentLinkBandwidthEntry, teLinkDescrMaxLspBandwidthPrio1=teLinkDescrMaxLspBandwidthPrio1, componentLinkBandwidthPriority=componentLinkBandwidthPriority, TeLinkEncodingType=TeLinkEncodingType, teLinkObjects=teLinkObjects, teLinkModuleReadOnlyCompliance=teLinkModuleReadOnlyCompliance, teLinkDescrMaxLspBandwidthPrio0=teLinkDescrMaxLspBandwidthPrio0, teLinkDescrMaxLspBandwidthPrio5=teLinkDescrMaxLspBandwidthPrio5, teLinkRemoteIpAddr=teLinkRemoteIpAddr, teLinkBandwidthGroup=teLinkBandwidthGroup, TeLinkSwitchingCapability=TeLinkSwitchingCapability, teLinkDescriptorTable=teLinkDescriptorTable, teLinkDescrMaxLspBandwidthPrio7=teLinkDescrMaxLspBandwidthPrio7, componentLinkCurrentProtection=componentLinkCurrentProtection, teLinkBandwidthTable=teLinkBandwidthTable, PYSNMP_MODULE_ID=teLinkStdMIB, teLinkBandwidthRowStatus=teLinkBandwidthRowStatus, teLinkSrlg=teLinkSrlg, teLinkDescrMaxLspBandwidthPrio6=teLinkDescrMaxLspBandwidthPrio6, componentLinkDescrStorageType=componentLinkDescrStorageType, componentLinkDescrIndication=componentLinkDescrIndication, componentLinkStorageType=componentLinkStorageType, teLinkSrlgStorageType=teLinkSrlgStorageType, teLinkWorkingPriority=teLinkWorkingPriority, componentLinkBandwidthTable=componentLinkBandwidthTable, componentLinkRowStatus=componentLinkRowStatus, teLinkMetric=teLinkMetric, componentLinkTable=componentLinkTable, teLinkEntry=teLinkEntry, teLinkDescriptorEntry=teLinkDescriptorEntry, componentLinkPreferredProtection=componentLinkPreferredProtection, componentLinkDescriptorEntry=componentLinkDescriptorEntry, teLinkDescrEncodingType=teLinkDescrEncodingType, teLinkSrlgTable=teLinkSrlgTable, componentLinkDescrInterfaceMtu=componentLinkDescrInterfaceMtu, teLinkIncomingIfId=teLinkIncomingIfId, componentLinkDescriptorTable=componentLinkDescriptorTable, teLinkBandwidthStorageType=teLinkBandwidthStorageType, teLinkDescrMaxLspBandwidthPrio2=teLinkDescrMaxLspBandwidthPrio2, teLinkDescriptorId=teLinkDescriptorId, TeLinkBandwidth=TeLinkBandwidth, teLinkStorageType=teLinkStorageType, componentLinkDescrMaxLspBandwidthPrio3=componentLinkDescrMaxLspBandwidthPrio3, componentLinkDescrMaxLspBandwidthPrio7=componentLinkDescrMaxLspBandwidthPrio7, teLinkRowStatus=teLinkRowStatus, teLinkModuleFullCompliance=teLinkModuleFullCompliance, componentLinkDescrMinLspBandwidth=componentLinkDescrMinLspBandwidth)



#
# PySNMP MIB module DSA-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DSA-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:11:07 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueSizeConstraint, ValueRangeConstraint, ConstraintsIntersection, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueSizeConstraint", "ValueRangeConstraint", "ConstraintsIntersection", "ConstraintsUnion")
( DistinguishedName, applIndex, ) = mibBuilder.importSymbols("NETWORK-SERVICES-MIB", "DistinguishedName", "applIndex")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, Gauge32, iso, NotificationType, Bits, Counter32, mib_2, ModuleIdentity, Integer32, ObjectIdentity, IpAddress, TimeTicks, MibIdentifier, Counter64, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "Gauge32", "iso", "NotificationType", "Bits", "Counter32", "mib-2", "ModuleIdentity", "Integer32", "ObjectIdentity", "IpAddress", "TimeTicks", "MibIdentifier", "Counter64")
( DisplayString, TimeStamp, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TimeStamp", "TextualConvention")
dsaMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 29))
if mibBuilder.loadTexts: dsaMIB.setLastUpdated('9311250000Z')
if mibBuilder.loadTexts: dsaMIB.setOrganization('IETF Mail and Directory Management Working\n                         Group')
if mibBuilder.loadTexts: dsaMIB.setContactInfo('        Glenn Mansfield\n\n              Postal: AIC Systems Laboratory\n                      6-6-3, Minami Yoshinari\n                      Aoba-ku, Sendai, 989-32\n                      JP\n\n              Tel:    +81 22 279 3310\n              Fax:    +81 22 279 3640\n              E-Mail: glenn@aic.co.jp')
if mibBuilder.loadTexts: dsaMIB.setDescription(' The MIB module for monitoring Directory System Agents.')
dsaOpsTable = MibTable((1, 3, 6, 1, 2, 1, 29, 1), )
if mibBuilder.loadTexts: dsaOpsTable.setDescription(' The table holding information related to the\n                DSA operations.')
dsaOpsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 29, 1, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: dsaOpsEntry.setDescription(' Entry containing operations related statistics\n                for a DSA.')
dsaAnonymousBinds = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaAnonymousBinds.setDescription(' Number of anonymous  binds to this DSA from DUAs\n                since application start.')
dsaUnauthBinds = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaUnauthBinds.setDescription(' Number of un-authenticated binds to this\n                DSA since application start.')
dsaSimpleAuthBinds = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaSimpleAuthBinds.setDescription(' Number of binds to this DSA that were authenticated\n                using simple authentication procedures since\n                application start.')
dsaStrongAuthBinds = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaStrongAuthBinds.setDescription(' Number of binds to this DSA that were authenticated\n                using the strong authentication procedures since\n                application start. This includes the binds that were\n                authenticated using external authentication procedures.')
dsaBindSecurityErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaBindSecurityErrors.setDescription(' Number of bind operations that have been rejected\n                by this DSA due to inappropriateAuthentication or\n                invalidCredentials.')
dsaInOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaInOps.setDescription(' Number of operations forwarded to this DSA\n                from DUAs or other DSAs since application\n                start up.')
dsaReadOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaReadOps.setDescription(' Number of read operations serviced by\n                this DSA since application startup.')
dsaCompareOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaCompareOps.setDescription(' Number of compare operations serviced by\n                this DSA  since application startup.')
dsaAddEntryOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaAddEntryOps.setDescription(' Number of addEntry operations serviced by\n                this DSA since application startup.')
dsaRemoveEntryOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaRemoveEntryOps.setDescription(' Number of removeEntry operations serviced by\n                this DSA since application startup.')
dsaModifyEntryOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaModifyEntryOps.setDescription(' Number of modifyEntry operations serviced by\n                this DSA since application startup.')
dsaModifyRDNOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaModifyRDNOps.setDescription(' Number of modifyRDN operations serviced by\n                this DSA since application startup.')
dsaListOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaListOps.setDescription(' Number of list operations serviced by\n                this DSA since application startup.')
dsaSearchOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaSearchOps.setDescription(' Number of search operations- baseObjectSearches,\n                oneLevelSearches and  subTreeSearches, serviced\n                by this DSA  since application startup.')
dsaOneLevelSearchOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaOneLevelSearchOps.setDescription(' Number of oneLevelSearch operations serviced\n                by this DSA since application startup.')
dsaWholeTreeSearchOps = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaWholeTreeSearchOps.setDescription(' Number of wholeTreeSearch operations serviced\n                by this DSA since application startup.')
dsaReferrals = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaReferrals.setDescription(' Number of referrals returned by this DSA in response\n                to requests for operations since application startup.')
dsaChainings = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaChainings.setDescription(' Number of operations forwarded by this DSA\n                to other DSAs since application startup.')
dsaSecurityErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaSecurityErrors.setDescription(' Number of operations forwarded to this DSA\n                which did not meet the security requirements. ')
dsaErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 1, 1, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaErrors.setDescription(' Number of operations that could not be serviced\n                due to errors other than security errors, and\n                referrals.\n                A partially serviced operation will not be counted\n                as an error.\n                The errors include NameErrors, UpdateErrors, Attribute\n                errors and ServiceErrors.')
dsaEntriesTable = MibTable((1, 3, 6, 1, 2, 1, 29, 2), )
if mibBuilder.loadTexts: dsaEntriesTable.setDescription(' The table holding information related to the\n\n                entry statistics and cache performance of the DSAs.')
dsaEntriesEntry = MibTableRow((1, 3, 6, 1, 2, 1, 29, 2, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: dsaEntriesEntry.setDescription(' Entry containing statistics pertaining to entries\n                held by a DSA.')
dsaMasterEntries = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 2, 1, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaMasterEntries.setDescription(' Number of entries mastered in the DSA.')
dsaCopyEntries = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 2, 1, 2), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaCopyEntries.setDescription(' Number of entries for which systematic (slave)\n                copies are maintained in the DSA.')
dsaCacheEntries = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 2, 1, 3), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaCacheEntries.setDescription(' Number of entries cached (non-systematic copies) in\n                the DSA. This will include the entries that are\n                cached partially. The negative cache is not counted.')
dsaCacheHits = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaCacheHits.setDescription(' Number of operations that were serviced from\n                the locally held cache since application\n                startup.')
dsaSlaveHits = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaSlaveHits.setDescription(' Number of operations that were serviced from\n                the locally held object replications [ shadow\n                entries] since application startup.')
dsaIntTable = MibTable((1, 3, 6, 1, 2, 1, 29, 3), )
if mibBuilder.loadTexts: dsaIntTable.setDescription(' Each row of this table contains some details\n                      related to the history of the interaction\n                      of the monitored DSAs with their respective\n                      peer DSAs.')
dsaIntEntry = MibTableRow((1, 3, 6, 1, 2, 1, 29, 3, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"), (0, "DSA-MIB", "dsaIntIndex"))
if mibBuilder.loadTexts: dsaIntEntry.setDescription(' Entry containing interaction details of a DSA\n                      with a peer DSA.')
dsaIntIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: dsaIntIndex.setDescription(' Together with applIndex it forms the unique key to\n                identify the conceptual row which contains useful info\n                on the (attempted) interaction between the DSA (referred\n                to by applIndex) and a peer DSA.')
dsaName = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 3, 1, 2), DistinguishedName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaName.setDescription(' Distinguished Name of the peer DSA to which this\n                entry pertains.')
dsaTimeOfCreation = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 3, 1, 3), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaTimeOfCreation.setDescription(' The value of sysUpTime when this row was created.\n                If the entry was created before the network management\n                subsystem was initialized, this object will contain\n                a value of zero.')
dsaTimeOfLastAttempt = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 3, 1, 4), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaTimeOfLastAttempt.setDescription(' The value of sysUpTime when the last attempt was made\n                to contact this DSA. If the last attempt was made before\n                the network management subsystem was initialized, this\n                object will contain a value of zero.')
dsaTimeOfLastSuccess = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 3, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaTimeOfLastSuccess.setDescription(' The value of sysUpTime when the last attempt made to\n                contact this DSA was successful. If there have\n                been no successful attempts this entry will have a value\n                of zero. If the last successful attempt was made before\n                the network management subsystem was initialized, this\n                object will contain a value of zero.')
dsaFailuresSinceLastSuccess = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 3, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaFailuresSinceLastSuccess.setDescription(' The number of failures since the last time an\n                attempt to contact this DSA was successful. If\n                there has been no successful attempts, this counter\n                will contain the number of failures since this entry\n                was created.')
dsaFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 3, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaFailures.setDescription(' Cumulative failures since the creation of\n                this entry.')
dsaSuccesses = MibTableColumn((1, 3, 6, 1, 2, 1, 29, 3, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsaSuccesses.setDescription(' Cumulative successes since the creation of\n                this entry.')
dsaConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 29, 4))
dsaGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 29, 4, 1))
dsaCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 29, 4, 2))
dsaOpsCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 29, 4, 2, 1)).setObjects(*(("DSA-MIB", "dsaOpsGroup"),))
if mibBuilder.loadTexts: dsaOpsCompliance.setDescription('The compliance statement for SNMPv2 entities\n                    which implement the DSA-MIB for monitoring\n                    DSA operations.')
dsaEntryCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 29, 4, 2, 2)).setObjects(*(("DSA-MIB", "dsaOpsGroup"), ("DSA-MIB", "dsaEntryGroup"),))
if mibBuilder.loadTexts: dsaEntryCompliance.setDescription('The compliance statement for SNMPv2 entities\n                    which implement the DSA-MIB for monitoring\n                    DSA operations,  entry statistics and cache\n                    performance.')
dsaIntCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 29, 4, 2, 3)).setObjects(*(("DSA-MIB", "dsaOpsGroup"), ("DSA-MIB", "dsaIntGroup"),))
if mibBuilder.loadTexts: dsaIntCompliance.setDescription(' The compliance statement  for SNMPv2  entities\n                      which implement the DSA-MIB for monitoring DSA\n                      operations and the interaction of the DSA with\n                      peer DSAs.')
dsaOpsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 29, 4, 1, 1)).setObjects(*(("DSA-MIB", "dsaAnonymousBinds"), ("DSA-MIB", "dsaUnauthBinds"), ("DSA-MIB", "dsaSimpleAuthBinds"), ("DSA-MIB", "dsaStrongAuthBinds"), ("DSA-MIB", "dsaBindSecurityErrors"), ("DSA-MIB", "dsaInOps"), ("DSA-MIB", "dsaReadOps"), ("DSA-MIB", "dsaCompareOps"), ("DSA-MIB", "dsaAddEntryOps"), ("DSA-MIB", "dsaRemoveEntryOps"), ("DSA-MIB", "dsaModifyEntryOps"), ("DSA-MIB", "dsaModifyRDNOps"), ("DSA-MIB", "dsaListOps"), ("DSA-MIB", "dsaSearchOps"), ("DSA-MIB", "dsaOneLevelSearchOps"), ("DSA-MIB", "dsaWholeTreeSearchOps"), ("DSA-MIB", "dsaReferrals"), ("DSA-MIB", "dsaChainings"), ("DSA-MIB", "dsaSecurityErrors"), ("DSA-MIB", "dsaErrors"),))
if mibBuilder.loadTexts: dsaOpsGroup.setDescription(' A collection of objects for monitoring the DSA\n                      operations.')
dsaEntryGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 29, 4, 1, 2)).setObjects(*(("DSA-MIB", "dsaMasterEntries"), ("DSA-MIB", "dsaCopyEntries"), ("DSA-MIB", "dsaCacheEntries"), ("DSA-MIB", "dsaCacheHits"), ("DSA-MIB", "dsaSlaveHits"),))
if mibBuilder.loadTexts: dsaEntryGroup.setDescription(' A collection of objects for monitoring the DSA\n                      entry statistics and cache performance.')
dsaIntGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 29, 4, 1, 3)).setObjects(*(("DSA-MIB", "dsaName"), ("DSA-MIB", "dsaTimeOfCreation"), ("DSA-MIB", "dsaTimeOfLastAttempt"), ("DSA-MIB", "dsaTimeOfLastSuccess"), ("DSA-MIB", "dsaFailuresSinceLastSuccess"), ("DSA-MIB", "dsaFailures"), ("DSA-MIB", "dsaSuccesses"),))
if mibBuilder.loadTexts: dsaIntGroup.setDescription(" A collection of objects for monitoring the DSA's\n                      interaction with peer DSAs.")
mibBuilder.exportSymbols("DSA-MIB", dsaErrors=dsaErrors, dsaOpsGroup=dsaOpsGroup, dsaTimeOfLastSuccess=dsaTimeOfLastSuccess, dsaGroups=dsaGroups, dsaWholeTreeSearchOps=dsaWholeTreeSearchOps, dsaConformance=dsaConformance, dsaOneLevelSearchOps=dsaOneLevelSearchOps, dsaBindSecurityErrors=dsaBindSecurityErrors, dsaOpsEntry=dsaOpsEntry, dsaSuccesses=dsaSuccesses, dsaOpsCompliance=dsaOpsCompliance, dsaSearchOps=dsaSearchOps, dsaMasterEntries=dsaMasterEntries, dsaTimeOfLastAttempt=dsaTimeOfLastAttempt, dsaUnauthBinds=dsaUnauthBinds, dsaEntryCompliance=dsaEntryCompliance, dsaFailuresSinceLastSuccess=dsaFailuresSinceLastSuccess, dsaMIB=dsaMIB, dsaSecurityErrors=dsaSecurityErrors, dsaModifyEntryOps=dsaModifyEntryOps, dsaIntCompliance=dsaIntCompliance, dsaName=dsaName, dsaOpsTable=dsaOpsTable, dsaIntIndex=dsaIntIndex, dsaTimeOfCreation=dsaTimeOfCreation, dsaChainings=dsaChainings, dsaInOps=dsaInOps, dsaCacheEntries=dsaCacheEntries, dsaEntryGroup=dsaEntryGroup, dsaEntriesEntry=dsaEntriesEntry, dsaStrongAuthBinds=dsaStrongAuthBinds, dsaIntEntry=dsaIntEntry, dsaSimpleAuthBinds=dsaSimpleAuthBinds, dsaReadOps=dsaReadOps, dsaRemoveEntryOps=dsaRemoveEntryOps, dsaModifyRDNOps=dsaModifyRDNOps, dsaFailures=dsaFailures, dsaListOps=dsaListOps, dsaCacheHits=dsaCacheHits, dsaIntTable=dsaIntTable, dsaEntriesTable=dsaEntriesTable, PYSNMP_MODULE_ID=dsaMIB, dsaCompliances=dsaCompliances, dsaCompareOps=dsaCompareOps, dsaCopyEntries=dsaCopyEntries, dsaSlaveHits=dsaSlaveHits, dsaAnonymousBinds=dsaAnonymousBinds, dsaIntGroup=dsaIntGroup, dsaReferrals=dsaReferrals, dsaAddEntryOps=dsaAddEntryOps)
